//
//  PCQRCodeReader.h
//  PayControl
//
//  Created by Roman Kolesnichenko on 31.08.16.
//  Copyright © 2016 SafeTech. All rights reserved.
//

#import <UIKit/UIKit.h>

@class PCQRCodeReader;
@class PCQRCode;

/** Типы QR-кода которые сканер будет воспринимать как валидные */
typedef NS_OPTIONS(NSUInteger, PCQRCodeAllowedType)
{
    /** QR-код ключа */
    PCQRCodeAllowedTypeKey                = 1 << 0,
    /** QR-код транзакции */
    PCQRCodeAllowedTypeTransaction        = 1 << 1
};

/**
 Протокол сканера QR кода
 */
@protocol PCQRCodeReaderDelegate <NSObject>
/**
 Вызывается, когда значение QR кода и его тип распознаны и валидны 
 @see property PCQRCodeReader.allowedQRCodeType - PCQRCodeAllowedType
 @param qrCode объект QR кода в зависимости от типа отканированного кода - PCKeyQRCode или PCTransactionQRCode унаследованные от PCQRCode
 */
- (void)codeDidRecognized:(PCQRCode* _Nonnull)qrCode;

@optional

/**
  Вызывается при обнаружении невалидного QR-кода 
  @see property allowedQRCodeType - PCQRCodeAllowedType.
 +*/
- (void)wrongCodeHasBeenScanned;

/**
 Вызывается, когда пользователь отменил сканирование
 */
- (void)scanningCancelled;

@end

/** Сканер QR-кода. 
 
 ## Пример использования
 
 PCQRCodeReader *qrReaderViewControler = [PCQRCodeReader new];
 
 qrReaderViewControler.delegate = self;
 
 qrReaderViewControler.allowedQRCodeType = PCQRCodeAllowedTypeTransaction;

 [qrReaderViewControler showWithParentViewController:self animated:YES];

 */
@interface PCQRCodeReader : UIViewController

/// ****************************************************************************
/// @name Методы экземпляра
/// ****************************************************************************

/** Показ экрана сканера QR-кода. Опционально. Можно использовать стандартыне методы перехода/отображения вьюконтроллера.
 @param parentViewController родительский вьюконтроллер из которого происходит переход
 @param animated показвать анимацию перехода
 */
- (void)showWithParentViewController:(UIViewController* _Nonnull)parentViewController animated:(BOOL)animated;

/** Отмена экрана сканера QR-кода. Опционально.
 */
- (void)dissmissQRViewController;

/// ****************************************************************************
/// @name Свойства
/// ****************************************************************************

/** Делегат, реализующий методы протокола сканера см. PCQRCodeReaderDelegate */
@property(nonatomic, weak, nullable) id <PCQRCodeReaderDelegate> delegate;

/** textToShow - Информационный текст отображающийся при старте сканера. */
@property(nonatomic, strong, nullable) NSString  *textToShow;

/** Текст, который показывается при сканировании неверного QR кода */
@property(nonatomic, strong, nullable) NSString  *invalidCodeText;

/** YES - показ и закрытие вьюконтроллера сканера происходит с анимацией, NO - без анимации */
@property(nonatomic, assign) BOOL animated;

/**
 Типы QR-кода которые сканер будет воспринимать как валидные см. PCQRCodeAllowedType
 @warning По умолчанию валидными считаются QR-коды ключа и транзакции (PCQRCodeAllowedTypeKey | PCQRCodeAllowedTypeTransaction)
 */
@property(nonatomic, assign) PCQRCodeAllowedType allowedQRCodeType;

/**
 Слой-маска отображающийся поверх сканируемого изображения, при этом другие надписи скрываются
  */
@property(nonatomic, strong, nullable) UIView *maskView;


@end
